==> landing-page-webflow-scripts-1.5.4.tgz: package/src/shared/language-switch.js <==
/**
 * language switch in the toolbar
 * @type {{
 *   init: languageSwitch.init,
 *   findElementByLanguage: (function(*): *),
 *   getLanguage: (function(): string | boolean),
 *   getElementsLanguage(*=): *,
 *   setOnClickListenersToAllElements: languageSwitch.setOnClickListenersToAllElements,
 *   replaceMainElementWithLanguage: languageSwitch.replaceMainElementWithLanguage
 * }}
 */
import { pushTagToGTM } from '../util/gtm/cos-gtm';
import { languageSwitchSelect } from '../util/gtm/tags-collection';

export const languageSwitch = (() => ({
  init: function () {
    const language = languageSwitch.getLanguage();

    if (language === 'de') {
      languageSwitch.setOnClickListenersToAllElements(language);
    } else {
      languageSwitch.replaceMainElementWithLanguage(language);
    }

    if (language === 'ru') {
      languageSwitch.adjustStylesForRussianLanguage();
    }
  },
  getLanguage: function () {
    let subdomain = window.location.host.split('.')[1] ? window.location.host.split('.')[0] : false;

    subdomain = subdomain === 'www' ? 'de' : subdomain;

    return subdomain;
  },
  getElementsLanguage(element) {
    return $(element).attr('class').split(' ')[1];
  },
  findElementByLanguage: function (language) {
    return $('.text-wrapper.' + language);
  },
  setOnClickListenersToAllElements: function (currentLanguage) {
    let $elements = $('.text-wrapper');
    $elements.each(function () {
      let elementLanguage = languageSwitch.getElementsLanguage(this);

      if (currentLanguage === elementLanguage) {
        return;
      }

      if (elementLanguage !== 'de') {
        $(this).on('click', function () {
          window.open('https://' + elementLanguage + '.caronsale.de', '_self');
        });
      } else {
        $(this).on('click', function () {
          window.open('https://caronsale.de', '_self');
        });
      }

      pushTagToGTM({
        ...languageSwitchSelect,
        value: currentLanguage.toUpperCase()
      });
    });
  },
  replaceMainElementWithLanguage: function (language) {
    const $activeElement = this.findElementByLanguage('active').removeClass('active');
    const $element = this.findElementByLanguage(language).addClass('active');

    const $closest = $element.closest('.wg-dropdown-link');

    $activeElement.remove();
    $element.remove();

    $closest.append($activeElement);
    $('.wg-toggle').append($element);

    languageSwitch.setOnClickListenersToAllElements(language);
  },
  adjustStylesForRussianLanguage: function () {
    // toolbar nav link
    $('.nav-link').css({
      'font-size': '12px',
      padding: '12px 10px'
    });

    $('.secondary-button').css({
      'font-size': '14px',
      'font-weight': 'bold'
    });

    $('.primary-button').find('.text-block').css({
      'font-size': '14px'
    });

    // demo page
    $('.transport').find('.text-block').css({
      'font-size': '12px'
    });

    // seller page
    $('input[type=submit]').css({
      'font-size': '12px',
      'min-width': '180px'
    });

    // career page
    $('.primary-button-2').find('.text-block').css({
      'font-size': '12px'
    });
  }
}))();

==> landing-page-webflow-scripts-1.5.7.tgz: package/src/shared/language-switch.js <==
/**
 * language switch in the toolbar
 * @type {{
 *   init: languageSwitch.init,
 *   findElementByLanguage: (function(*): *),
 *   getLanguage: (function(): string | boolean),
 *   getElementsLanguage(*=): *,
 *   setOnClickListenersToAllElements: languageSwitch.setOnClickListenersToAllElements,
 *   replaceMainElementWithLanguage: languageSwitch.replaceMainElementWithLanguage
 * }}
 */
import { pushTagToGTM } from '../util/gtm/cos-gtm';
import { languageSwitchSelect } from '../util/gtm/tags-collection';

export const languageSwitch = (() => ({
  init: function () {
    const language = languageSwitch.getLanguage();

    if (language === 'de') {
      languageSwitch.setOnClickListenersToAllElements(language);
    } else {
      languageSwitch.replaceMainElementWithLanguage(language);
    }

    if (language === 'ru') {
      languageSwitch.adjustStylesForRussianLanguage();
    }
  },
  getLanguage: function () {
    let subdomain = window.location.host.split('.')[1] ? window.location.host.split('.')[0] : false;

    subdomain = subdomain === 'www' ? 'de' : subdomain;

    return subdomain;
  },
  getElementsLanguage(element) {
    return $(element).attr('class').split(' ')[1];
  },
  findElementByLanguage: function (language) {
    return $('.text-wrapper.' + language);
  },
  setOnClickListenersToAllElements: function (currentLanguage) {
    let $elements = $('.text-wrapper');
    $elements.each(function () {
      let elementLanguage = languageSwitch.getElementsLanguage(this);

      if (currentLanguage === elementLanguage) {
        return;
      }

      if (elementLanguage !== 'de') {
        $(this).on('click', function () {
          window.open('https://' + elementLanguage + '.caronsale.de', '_self');
        });
      } else {
        $(this).on('click', function () {
          window.open('https://caronsale.de', '_self');
        });
      }

      $(this).on('click', function () {
        pushTagToGTM({
          ...languageSwitchSelect,
          value: elementLanguage.toUpperCase()
        });
      });
    });
  },
  replaceMainElementWithLanguage: function (language) {
    const $activeElement = this.findElementByLanguage('active').removeClass('active');
    const $element = this.findElementByLanguage(language).addClass('active');

    const $closest = $element.closest('.wg-dropdown-link');

    $activeElement.remove();
    $element.remove();

    $closest.append($activeElement);
    $('.wg-toggle').append($element);

    languageSwitch.setOnClickListenersToAllElements(language);
  },
  adjustStylesForRussianLanguage: function () {
    // toolbar nav link
    $('.nav-link').css({
      'font-size': '12px',
      padding: '12px 10px'
    });

    $('.secondary-button').css({
      'font-size': '14px',
      'font-weight': 'bold'
    });

    $('.primary-button').find('.text-block').css({
      'font-size': '14px'
    });

    // demo page
    $('.transport').find('.text-block').css({
      'font-size': '12px'
    });

    // seller page
    $('input[type=submit]').css({
      'font-size': '12px',
      'min-width': '180px'
    });

    // career page
    $('.primary-button-2').find('.text-block').css({
      'font-size': '12px'
    });
  }
}))();
